<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Włączono Tryb samolotowy</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Wyłączono Tryb samolotowy</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Tryb samolotowy</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Ustawienia trybu samolotowego</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Tryb samolotowy</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Moje urządzenia</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ustawienia Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Wyłączony</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
        <translation>Wyłącz Tryb Samolotowy, aby połączyć się z Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ustawienia Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 połączono</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Łączenie...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Wyłączony</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 połączono</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nie połączono</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Wyłączone</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Jasność</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ustawienia ekranu</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Ustawienia ekranu</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Jasność</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Pon</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Wt</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Śr</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Czw</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pt</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sob</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj układ klawiatury</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data i czas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Format 12-godzinny</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Format 24-godzinny</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Ustawienia czasu</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Otwórz kalendarz</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Poniedziałek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Wtorek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Środa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Czwartek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Piątek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Niedziela</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>poniedziałek</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>wtorek</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>środa</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>czwartek</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>piątek</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>niedziela</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Inne urządzenia</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Tryb Nie przeszkadzać</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Ustawienia trybu Nie przeszkadzać</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Włączono tryb Nie przeszkadzać</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Wyłączono tryb Nie przeszkadzać</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Tryb Nie przeszkadzać</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Komfort oczu</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Włączono Komfort oczu</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Wyłączono Komfort oczu</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ustawienia ekranu</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Komfort oczu</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Motyw</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Wł</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Wył</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Jasny</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Ciemny</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Wyłącz komfort oczu</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Włącz komfort oczu</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Ustawienia ekranu</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Motyw: Jasny</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Motyw: Ciemny</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Motyw: Automatycznie</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Efekty wizualne</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Jasny</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Ciemny</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Motyw</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Położenie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Ustawienia doku</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Brak wiadomości</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Ustawienia powiadomień</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Powiadomień</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Wyłącz tryb Nie przeszkadzać</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Włącz tryb Nie przeszkadzać</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Powiadomienie</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Klawiatura ekranowa</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Wysoka wydajność</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Zrównoważony</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Oszczędzanie energii</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Zrównoważona wydajność</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Ustawienia zasilania</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Poziom: %1, pozostało: %2min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Poziom: %1, pozostało: %2:%3</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Ładowanie %1, %2min do końca</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Ładowanie %1, %2:%3 do końca</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Pojemność %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Ładowanie %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Pojemność %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Pojemność %1, w pełni naładowana</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Pojemność %1, brak ładowania</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Ładowanie, obliczanie szacowanego czasu ładowania</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Obliczanie pozostałego czasu użytkowania</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 min pozostało</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 godz %2 min pozostało</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Nie ładuje</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>W pełni naładowany</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Ładowanie, %1 min do naładowania</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Ładowanie, %1 godz %2 min do naładowania</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Poziom: %1, %2 godz. pozostało</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 godz. pozostało</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Ładowanie %1, %2 godz. do końca</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Ładowanie, %1 godz. do końca</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Ustawienia zasilania</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernacja</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ustawienia zasilania</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aktualizuj i zamknij</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aktualizuj i uruchom ponownie</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Zmień użytkownika</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Księżycowy</translation>
    </message>
    <message>
        <source>y</source>
        <translation>r</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Poniedziałek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Wtorek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Środa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Czwartek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Piątek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Niedziela</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Sty</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Lut</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Kwi</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Maj</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Cze</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Lip</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Sie</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Wrz</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Paź</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Lis</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Gru</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Otwórz kalendarz</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>poniedziałek</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>wtorek</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>środa</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>czwartek</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>piątek</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>niedziela</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Głośność</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ustawienia dźwięku</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Wyłącz wyciszenie</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ustawienia dźwięku</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Brak urządzeń wyjściowych</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Głośność %1</translation>
    </message>
</context>
</TS>